```{toctree}
:hidden:

Installing <https://shrine-maiden-heavy-industries.github.io/torii-hdl/install.html#installing-board-definitions>

gowin/index
altera/index
lattice/index
quicklogic/index
xilinx/index

Torii HDL <https://shrine-maiden-heavy-industries.github.io/torii-hdl/>

```

```{toctree}
:caption: Development
:hidden:

Source Code <https://github.com/shrine-maiden-heavy-industries/torii-boards/>
Contributing <https://github.com/shrine-maiden-heavy-industries/torii-boards/blob/main/CONTRIBUTING.md>

changelog
license
```

# Torii-HDL Board Definitions

This package provides board definition files for various popular FPGA development boards for [Torii](https://github.com/shrine-maiden-heavy-industries/torii-hdl). They are grouped by FPGA vendor.
